NodeKind

Enum NodeKind 

#[non_exhaustive]
pub enum NodeKind {
Show 31 variants Document, Section, Paragraph, Heading { level: u8, }, FencedCodeBlock, IndentedCodeBlock, BlockQuote, BulletList, OrderedList, ListItem, ThematicBreak, HtmlBlock, Table, TableRow, TableHeader, TableDelimiterRow, LinkReferenceDefinition, FrontMatter, Emphasis, StrongEmphasis, InlineCode, Link, Image, Strikethrough, HardLineBreak, SoftLineBreak, InfoString, CodeFenceContent, Inline, Text, Unknown,
}
Classification of markdown node types from the tree-sitter CST.

These represent the semantic meaning of each node, useful for rendering decisions and command dispatch.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Document



Section



Paragraph



Heading

Fields

level: u8


FencedCodeBlock



IndentedCodeBlock



BlockQuote



BulletList



OrderedList



ListItem



ThematicBreak



HtmlBlock



Table



TableRow



TableHeader



TableDelimiterRow



LinkReferenceDefinition



FrontMatter



Emphasis



StrongEmphasis



InlineCode



Image



Strikethrough



HardLineBreak



SoftLineBreak



InfoString



CodeFenceContent



Inline



Text



Unknown

Implementations

Source

impl NodeKind

pub fn from_ts_kind(kind: &str) -> Self

Classify a tree-sitter node kind string.

pub fn is_block(&self) -> bool

True if this is a block-level element.

pub fn is_inline(&self) -> bool

True if this is an inline element.

pub fn is_container(&self) -> bool

True if this node can contain other blocks (is a container).